% Quokka3 example settingsfile for a multiwire measurement setup of a generic bifacial busburless solar cell
% simple generic bifacial rear-junction HJT cell with symmetric properties
% uses the "Probe" functionality to represent a 4-wire measurement setup
% assumes equally spaced alternating current / voltage wires with 5mm pitch


% (c) 2024 Andreas Fell

Syntax = 'generic';

SaveMaps = 1; % to be able to plot surface potentials

% sweeps the finger conductivity from very conductive to poorly conductive
% also changes between "default" and "Probe" reference voltage
% "default" is more representative of an interconnected cell in the module
% "Probe" is representative of the measurement in a cell tester using a multi-wire contacting setup
Sweep.Enable = 1;
Sweep.NGroups = 2;
Sweep.GroupA(1).Parameter = 'MetalFeature(1).Electrical.Rsheet';
Sweep.GroupA(1).Values = lin[1e-4,3e-2,5];
Sweep.GroupA(2).Parameter = 'MetalFeature(2).Electrical.Rsheet';
Sweep.GroupA(2).Values = lin[1e-4,3e-2,5];
Sweep.GroupB(1).Parameter = 'Solver.Electrical.JVVoltage.Type';
Sweep.GroupB(1).Values = ['default' 'Probe'];

Domain.DeviceType = 'semiconductor device';
Domain.Dimensions = 3;
Domain.Wz = 150 um;
Domain.Wx = 1 cm;
Domain.Wy = 0.6 mm;

Solver.SolutionType = 'light JV-curve';
Solver.JVCurve.VtermStepSize = 'coarse';

Solver.Electrical.SkinJ0nieff.Type = 'user-T';
Solver.Electrical.SkinJ0nieff.T = 298.15 K;
Solver.Illumination.Enable = 1;
Solver.Electrical.MetalModelType = 'finite-differences';
Solver.Electrical.BulkModelType = 'equivalent-circuit';
% equivalent-circuit mode is sufficiently accurate when investigating metallization and contacting effects, gives large speed boost
Solver.Electrical.JVVoltage.Type = 'Probe';
% uses the Probe voltages as reference voltage for JV algorithms and JV parameter calculation
% 'default' means using the applied voltage, which is applied to the PadFeatures (in this case the current wires)
Solver.Electrical.JVVoltage.NProbe = 'FrontVoltage';
Solver.Electrical.JVVoltage.PProbe = 'RearVoltage';

Optical.GenerationModelType = 'defined-generation';
Optical.DefinedGeneration.Type = 'uniform-Jgen';
Optical.DefinedGeneration.UniformJgen = 40 mA/cm2;
Optical.DefinedGeneration.IlluminationSide = 'front';
Optical.DefinedGeneration.IlluminationIntensity = 100 mW/cm2;

Bulk.Electrical.Recombination.Type = 'intrinsic';
Bulk.BackgroundDoping.SettingType = 'dopingtype-resistivity';
Bulk.BackgroundDoping.DopingType = 'n-type';
Bulk.BackgroundDoping.Resistivity = 1.5 Ohmcm;

SkinFeature(1).Name = 'FullFrontSkin';
SkinFeature(1).Geometry.Shape = 'full';
SkinFeature(1).Geometry.Plane = 'front';
SkinFeature(1).ElectricalModelType = 'lumped';
SkinFeature(1).Lumped.Electrical.RsheetEnable = 1;
SkinFeature(1).Lumped.Electrical.Rsheet = 150 Ohm;
SkinFeature(1).Lumped.Electrical.ConductionType = 'n-type';
SkinFeature(1).Lumped.Electrical.NonContactedRecombination.ModelType = 'J0';
SkinFeature(1).Lumped.Electrical.NonContactedRecombination.J0 = 2 fAcm-2;
SkinFeature(1).Lumped.Electrical.ContactedRecombination.ModelType = 'J0';
SkinFeature(1).Lumped.Electrical.ContactedRecombination.J0 = 2 fA/cm2;

SkinFeature(2).Name = 'FullRearSkin';
SkinFeature(2).Geometry.Shape = 'full';
SkinFeature(2).Geometry.Plane = 'rear';
SkinFeature(2).ElectricalModelType = 'lumped';
SkinFeature(2).Lumped.Electrical.RsheetEnable = 1;
SkinFeature(2).Lumped.Electrical.Rsheet = 150;
SkinFeature(2).Lumped.Electrical.ConductionType = 'p-type';
SkinFeature(2).Lumped.Electrical.ContactedRecombination.ModelType = 'J0';
SkinFeature(2).Lumped.Electrical.ContactedRecombination.J0= 2 fA/cm2;
SkinFeature(2).Lumped.Electrical.NonContactedRecombination.ModelType = 'J0';
SkinFeature(2).Lumped.Electrical.NonContactedRecombination.J0= 2 fA/cm2;

ContactFeature(1).Name = 'FrontContact';
ContactFeature(1).Geometry.Shape = 'rectangle';
ContactFeature(1).Geometry.Plane = 'front';
ContactFeature(1).Geometry.PositionX = 0;
ContactFeature(1).Geometry.PositionY = 0;
ContactFeature(1).Geometry.SizeX = 2 cm;
ContactFeature(1).Geometry.SizeY = 30 um;
ContactFeature(1).OhmicResistivity = 2e-3 Ohmcm2;

ContactFeature(2).Name = 'RearContact';
ContactFeature(2).Geometry.Shape = 'rectangle';
ContactFeature(2).Geometry.Plane = 'rear';
ContactFeature(2).Geometry.PositionX = 0;
ContactFeature(2).Geometry.PositionY = 0;
ContactFeature(2).Geometry.SizeX = 2 cm;
ContactFeature(2).Geometry.SizeY = 30 um;
ContactFeature(2).OhmicResistivity = 2e-3 Ohmcm2;

MetalFeature(1).Name = 'FrontFinger';
MetalFeature(1).Geometry.Shape = 'rectangle';
MetalFeature(1).Geometry.Plane = 'front';
MetalFeature(1).Geometry.PositionX = 0;
MetalFeature(1).Geometry.PositionY = 0;
MetalFeature(1).Geometry.SizeX = 2 cm;
MetalFeature(1).Geometry.SizeY = 30 um;
MetalFeature(1).Electrical.Polarity = 'n-type';
MetalFeature(1).Electrical.Rsheet = 3e-3 Ohm;

MetalFeature(2).Name = 'RearFinger';
MetalFeature(2).Geometry.Shape = 'rectangle';
MetalFeature(2).Geometry.Plane = 'rear';
MetalFeature(2).Geometry.PositionX = 0;
MetalFeature(2).Geometry.PositionY = 0;
MetalFeature(2).Geometry.SizeX = 2 cm;
MetalFeature(2).Geometry.SizeY = 30 um;
MetalFeature(2).Electrical.Polarity = 'p-type';
MetalFeature(2).Electrical.Rsheet = 3e-3 Ohm;

PadFeature(1).Name = 'FrontCurrentWires';
PadFeature(1).Geometry.Shape = 'rectangle';
PadFeature(1).Geometry.Plane = 'front';
PadFeature(1).Geometry.PositionX = 0;
PadFeature(1).Geometry.PositionY = 0;
PadFeature(1).Geometry.SizeX = 100 um;
PadFeature(1).Geometry.SizeY = 1.2 mm;
PadFeature(1).Geometry.RepetitionsX = 2;
PadFeature(1).Geometry.PitchX = 1 cm;
PadFeature(1).Electrical.Polarity = 'n-type';
PadFeature(1).Electrical.ContactResistivity = 1e-6;

PadFeature(2).Name = 'RearCurrentWires';
PadFeature(2).Geometry.Shape = 'rectangle';
PadFeature(2).Geometry.Plane = 'rear';
PadFeature(2).Geometry.PositionX = 0;
PadFeature(2).Geometry.PositionY = 0;
PadFeature(2).Geometry.SizeX = 100 um;
PadFeature(2).Geometry.SizeY = 1.2 mm;
PadFeature(2).Geometry.RepetitionsX = 2;
PadFeature(2).Geometry.PitchX = 1 cm;
PadFeature(2).Electrical.Polarity = 'p-type';
PadFeature(2).Electrical.ContactResistivity = 1e-6;

% PadFeatures 11 and 21 represent the voltage sense wires and must be electrically disconnected, otherwise it would be another current extracting wire
% it solely influences simulation result by optical shading
PadFeature(11).Name = 'FrontVoltageWire';
PadFeature(11).Geometry.Shape = 'rectangle';
PadFeature(11).Geometry.Plane = 'front';
PadFeature(11).Geometry.PositionX = 0.5 cm;
PadFeature(11).Geometry.PositionY = 0 mm;
PadFeature(11).Geometry.SizeX = 100 um;
PadFeature(11).Geometry.SizeY = 1.2 mm;
PadFeature(11).Electrical.Polarity = 'n-type';
PadFeature(11).Electrical.ContactResistivity = 1e10; % very high contact resistivity means electrically disconnected

PadFeature(21).Name = 'RearVoltageWire';
PadFeature(21).Geometry.Shape = 'rectangle';
PadFeature(21).Geometry.Plane = 'rear';
PadFeature(21).Geometry.PositionX = 0.5 cm;
PadFeature(21).Geometry.PositionY = 0 mm;
PadFeature(21).Geometry.SizeX = 100 um;
PadFeature(21).Geometry.SizeY = 1.2 mm;
PadFeature(21).Electrical.Polarity = 'p-type';
PadFeature(21).Electrical.ContactResistivity = 1e10; % very high contact resistivity means electrically disconnected

% the probes return the surface potential, in this case the voltage of the metal finger between the current wires
Probe(1).Name = 'FrontVoltage';
Probe(1).Plane = 'front';
Probe(1).PositionX = 0.5 cm;
Probe(1).PositionY = 0;

Probe(2).Name = 'RearVoltage';
Probe(2).Plane = 'rear';
Probe(2).PositionX = 0.5 cm;
Probe(2).PositionY = 0;